# Intentional - Local terminal output

[![Made for Intentional](https://img.shields.io/badge/made_for-intentional-blue)](https://intentional-ai.github.io/intentional/docs/home/)
[![PyPI - Version](https://img.shields.io/pypi/v/intentional-terminal.svg)](https://pypi.org/project/intentional-terminal)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/intentional-terminal.svg)](https://pypi.org/project/intentional-terminal)
[![Copier](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/copier-org/copier/master/img/badge/badge-grayscale-inverted-border-orange.json)](https://github.com/copier-org/copier)

Plugin that makes Intentional able to use a local terminal to communicate.

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```
sudo apt install portaudio19-dev
```

```console
pip install intentional-terminal
```

## License

`intentional` is distributed under the terms of the [AGPL](LICENSE.txt) license.
